
***** Basic regression by AMT 09/20/2012 / Precursor to full LP code by Early

****************************************************************************************
****************************************************************************************
********** housekeeping ****************************************************************
****************************************************************************************
****************************************************************************************

* force sort tsset again
sort ccode year
tsset ccode year, yearly

********** save the recession list for Table 1 ****************************** 
preserve
sort iso pk_fin year
list iso pk_norm pk_fin year if pk_bb==1
outsheet iso pk_norm pk_fin year ///
	using ../tables/table1_$today.csv ///
		if (pk_fin==1|pk_norm==1), replace comma
restore


* RHS 7 variable set
local rhs7 drprv dlrgdp dlcpi dlriy stir ltrate cay ///
		l.drprv l.dlrgdp l.dlcpi ///
		l.dlriy l.stir l.ltrate l.cay	
			
* standardizing RHS levels to historical mean, sd
		
* do some manual standardizing (to demean) the rhs set
* for proper simple path fcast

local rhslevels drprv dlrgdp dlcpi dlriy stir ltrate cay
foreach v of local rhslevels {
		gen tempv1 = `v'   
		egen tempv2 = std(tempv1)   
		replace `v'=tempv2
		drop tempv1 tempv2
		}

* types	of recession (4 bin)	
local type norm fin1 fin2 fin3
local debt prv pub	
  						
*** Sample period names: f1 = full sample; pt2 = post WWII sample
local p1 f1
local p2 pt2

*** create the year constraints for the two sample periods
local c1 year>=1870
local c2 year>1946

*** impulse response variables
local irvars lrgdp lriy lcpi rprv cay stir ltrate
* just gdp
local justgdp lrgdp

*** make LP graph titles
local tlrgdp "Real GDP per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

*** make graph subtitles 
local s2f1 "1870-2008"
local s2pt2 "1946-2008"

forvalues i=1/5 {
	foreach v of local irvars {
	
	if "`v'"=="stir" | "`v'"=="ltrate" | "`v'"=="cay" {
		gen `v'`i' = (f`i'.`v' - `v')
	}
	else {
		gen `v'`i' = 100*(f`i'.`v' - `v')
	}
	}
}

* labels for GDP path tables
label var lrgdp1 "Year 1"
label var lrgdp2 "Year 2"
label var lrgdp3 "Year 3"
label var lrgdp4 "Year 4"
label var lrgdp5 "Year 5"
label var pk_norm "Normal recession"
label var pk_fin "Financial recession"
label var pk_fin1 "Financial recession, lo boom"
label var pk_fin2 "Financial recession, med boom"
label var pk_fin3 "Financial recession, hi boom"
label var srx_prv "Excess credit"
label var srx_norm_prv "Exc cred x Norm recn"
label var srx_fin_prv  "Exc cred x Fin recn"

****************************************************************************************
****************************************************************************************
******** GDP IRFs only --- regressions, then plots *************************************
****************************************************************************************
****************************************************************************************

preserve

*********** Unconditional 2 bins N F ***********

foreach v of local justgdp {
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
			reg `v'`i' pk_norm pk_fin   if  core==1 & srx_prv~=., noconstant
			predict resid`i' , residuals // for scatter

			reg `v'`i' pk_norm pk_fin   if  core==1 , noconstant
			eststo h`i'
			test pk_fin=pk_norm // amt test
			estadd scalar p_diff1 = r(p)
			sum pk_norm if e(sample)
			estadd scalar Norm = r(sum)
			sum pk_fin if e(sample)
			estadd scalar Fin = r(sum)					
			}
		}
	}

esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin p_diff1) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths, 1 bin)

esttab h1 h2 h3 h4 h5 using ../tables/table4.tex , replace ///
	scalars(Norm Fin p_diff1) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths, Normal v. Financial Bins)

eststo clear

*********** Unconditional 4 bins N F1 F2 F3 ***********

foreach v of local justgdp {
	foreach t of local type {
		forvalues j=1/1 {
			gen b1_`v'_`t'_`p`j'' =0
			gen se1_`v'_`t'_`p`j'' =0
			}
		}
	}

foreach v of local justgdp {
	forvalues i =1/5 {
		forvalues j= 1/1 {

				reg `v'`i' pk_norm pk_fin1 pk_fin2 pk_fin3  if core==1, noconstant
				eststo h`i'
				
				test pk_fin1=pk_norm // amt test
				estadd scalar p_diff1 = r(p)
				test pk_fin2=pk_norm // amt test
				estadd scalar p_diff2 = r(p)
				test pk_fin3=pk_norm // amt test
				estadd scalar p_diff3 = r(p)
				sum pk_norm if e(sample)
				estadd scalar Norm = r(sum)
				sum pk_fin1 if e(sample)
				estadd scalar Fin1 = r(sum)
				sum pk_fin2 if e(sample)
				estadd scalar Fin2 = r(sum)
				sum pk_fin3 if e(sample)
				estadd scalar Fin3 = r(sum)
				
				foreach t of local type {
					qui replace b1_`v'_`t'_`p`j'' =  _b[pk_`t'] if _n == `i'+1
					qui replace se1_`v'_`t'_`p`j'' = _se[pk_`t'] if _n == `i'+1
				}
			}
		}
	}

* p_diff1 is p value for F test of coefficients: Normal = Financial Lo
* p_diff2 is p value for F test of coefficients: Normal = Financial Hi

esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin1 Fin2 Fin3 p_diff1 p_diff2 p_diff3) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths, 2 bins)

esttab h1 h2 h3 h4 h5 using ../tables/table5.tex , replace ///
	scalars(Norm Fin1 Fin2 Fin3 p_diff1 p_diff2 p_diff3) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths, Normal v. Financial Bins with Hi-Lo Excess Credit)

eststo clear

*********** Unconditional 2 bins N F + continuous excess credit ***********

* create norm paths + excess = 0/1/2/3, initial value =0
gen lrgdpn0=0 if _n==1
gen lrgdpn1=0 if _n==1
gen lrgdpn2=0 if _n==1
gen lrgdpn3=0 if _n==1
* createfin paths + excess = 0/1/2/3, initial value =0
gen lrgdpf0=0 if _n==1
gen lrgdpf1=0 if _n==1
gen lrgdpf2=0 if _n==1
gen lrgdpf3=0 if _n==1

foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		qui reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv if core==1, noconstant //alt
		qui reg `v'`i' pk_norm pk_fin if e(sample)==1, noconstant // null, same sample
		replace ssr0`v'=e(rss) if _n==`i'
		reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv  if core==1, noconstant
		eststo h`i'
		replace ssr1`v'=e(rss) if _n==`i'
		replace nobs`v'=e(N) if _n==`i'

		replace lrgdpn0 = _b[pk_norm] + 0*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpn1 = _b[pk_norm] + 1*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpn2 = _b[pk_norm] + 2*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpn3 = _b[pk_norm] + 3*_b[srx_norm_prv]   if _n == `i'+1
				
		replace lrgdpf0 = _b[pk_fin] + 0*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf1 = _b[pk_fin] + 1*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf2 = _b[pk_fin] + 2*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf3 = _b[pk_fin] + 3*_b[srx_fin_prv]   if _n == `i'+1

		test pk_fin=pk_norm // amt test
		estadd scalar p_diff1 = r(p)
		test srx_norm_prv=srx_fin_prv // amt test
		estadd scalar p_diffsrx = r(p)
		sum pk_norm if e(sample)
		estadd scalar Norm = r(sum)
		sum pk_fin if e(sample)
		estadd scalar Fin = r(sum)

				
		}
	}
}

sum ssr0
scalar ssr0_ = r(sum)
sum ssr1
scalar ssr1_ = r(sum)
sum nobs
scalar nobs_ = r(sum)
scalar df1=10
scalar df2=nobs_-20
scalar lm = ( (ssr0_-ssr1_)/df1 ) / ( ssr1_ / (df2) )
scalar psrx = Ftail(df1,df2,lm)

local note1 = "LM test: All excess credit coefficients equal zero: "
local note2 = "F("+string(df1)+","+string(df2) + ") = "+string(lm,"%9.3f") + "; "
local note3 = "p = "+string(psrx,"%9.3f")
local note0 = "`note1'"+"`note2'"+"`note3'"

* p_diff1 is p value for F test of coefficients: Normal = Financial
esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths)
esttab h1 h2 h3 h4 h5 using ../tables/table6.tex , replace ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita") ///
	title(Unconditional Paths, Normal v. Financial Bins and Excess Credit)

eststo clear
drop ssr0* ssr1* nobs*
scalar drop ssr0_ ssr1_ nobs_ df1 df2

*********** LP Conditional 2 bins (adds `rhs7' controls) 7 vars ***********

* force sort tsset again
sort ccode year
tsset ccode year, yearly

* country fixed effects CFE restricted regression coefficients
forvalues i =1/14 {
	gen      dum`i'=0
	replace  dum`i'= 1 - 1/14   if ccode==`i'
	replace  dum`i'=   - 1/14   if ccode~=`i'
	}

foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		qui reg `v'`i' pk_norm pk_fin  `rhs7' dum1-dum13 ///
			if core==1, noconstant //alt
		qui reg `v'`i' pk_bb `rhs7' dum1-dum13 ///
			if e(sample)==1, noconstant // null, same sample

		replace ssr0`v'=e(rss) if _n==`i'
		reg `v'`i' pk_norm pk_fin  `rhs7' dum1-dum13 ///
			if core==1, noconstant
		eststo h`i'
		replace ssr1`v'=e(rss) if _n==`i'
		replace nobs`v'=e(N) if _n==`i'
				
		test pk_fin=pk_norm // amt test
		estadd scalar p_diff1 = r(p)
		sum pk_norm if e(sample)
		estadd scalar Norm = r(sum)
		sum pk_fin if e(sample)
		estadd scalar Fin = r(sum)					

		}
	}
}

sum ssr0
scalar ssr0_ = r(sum)
sum ssr1
scalar ssr1_ = r(sum)
sum nobs
scalar nobs_ = r(sum)
scalar df1=10
scalar df2=nobs_ -20
scalar lmnew2 = ( (ssr0_-ssr1_)/df1 ) / ( ssr1_ / (df2) )
scalar psrxnew2 = Ftail(df1,df2,lmnew2)

local note1 = "LM test: pknorm-pkfin coeffs equal: "
local note2 = "F("+string(df1)+","+string(df2) + ") = "+string(lmnew2,"%9.3f") + "; "
local note3 = "p = "+string(psrxnew2,"%9.3f")
local note0 = "`note1'"+"`note2'"+"`note3'"

* p_diff1 is p value for F test of coefficients: Normal = Financial
esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins)

esttab h1 h2 h3 h4 h5 using ../tables/table7.tex , replace ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins)

eststo clear

drop ssr0* ssr1* nobs*
scalar drop ssr0_ ssr1_ nobs_ df1 df2


*********** LP Conditional 2 bins (adds `rhs7' controls) 7 vars, exGD years ***********

* force sort tsset again
sort ccode year
tsset ccode year, yearly

foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		qui reg `v'`i' pk_norm pk_fin  `rhs7' dum1-dum13 ///
			if core==1 & (year<1928|year>1946), noconstant //alt
		qui reg `v'`i' pk_bb `rhs7'  dum1-dum13 ///
			if e(sample)==1, noconstant // null, same sample

		replace ssr0`v'=e(rss) if _n==`i'
		reg `v'`i' pk_norm pk_fin  `rhs7' dum1-dum13 ///
			if core==1 & (year<1928|year>1946), noconstant
		eststo h`i'
		replace ssr1`v'=e(rss) if _n==`i'
		replace nobs`v'=e(N) if _n==`i'
				
		test pk_fin=pk_norm // amt test
		estadd scalar p_diff1 = r(p)
		sum pk_norm if e(sample)
		estadd scalar Norm = r(sum)
		sum pk_fin if e(sample)
		estadd scalar Fin = r(sum)					

		}
	}
}

sum ssr0
scalar ssr0_ = r(sum)
sum ssr1
scalar ssr1_ = r(sum)
sum nobs
scalar nobs_ = r(sum)
scalar df1=10
scalar df2=nobs_ -20
scalar lmnew2 = ( (ssr0_-ssr1_)/df1 ) / ( ssr1_ / (df2) )
scalar psrxnew2 = Ftail(df1,df2,lmnew2)

local note1 = "LM test: pknorm-pkfin coeffs equal: "
local note2 = "F("+string(df1)+","+string(df2) + ") = "+string(lmnew2,"%9.3f") + "; "
local note3 = "p = "+string(psrxnew2,"%9.3f")
local note0 = "`note1'"+"`note2'"+"`note3'"

* p_diff1 is p value for F test of coefficients: Normal = Financial
esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins, ExGD (year<1928|year>1946))

esttab h1 h2 h3 h4 h5 using ../tables/table7exGD.tex , replace ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins, ExGD (year<1928|year>1946))

eststo clear

drop ssr0* ssr1* nobs*
scalar drop ssr0_ ssr1_ nobs_ df1 df2

*********** LP Conditional 2 bins + cts exc cred (adds `rhs7' controls) 7 vars  *********

* force sort tsset again
sort ccode year
tsset ccode year, yearly

* norm paths + excess = 0/1/2/3, initial value =0
gen lrgdpnlp0=0 if _n==1
gen lrgdpnlp1=0 if _n==1
gen lrgdpnlp2=0 if _n==1
gen lrgdpnlp3=0 if _n==1
* fin paths + excess = 0/1/2/3, initial value =0
gen lrgdpflp0=0 if _n==1
gen lrgdpflp1=0 if _n==1
gen lrgdpflp2=0 if _n==1
gen lrgdpflp3=0 if _n==1

*cts
gen lrgdpf050=0 if _n==1
gen lrgdpf175=0 if _n==1
gen lrgdpf275=0 if _n==1
gen lrgdpf375=0 if _n==1

foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		qui reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7' dum1-dum13 ///
			if core==1, noconstant //alt
		qui reg `v'`i' pk_norm pk_fin `rhs7' dum1-dum13 ///
			if e(sample)==1, noconstant // null, same sample
			predict residlp`i' , residuals // for scatter

		replace ssr0`v'=e(rss) if _n==`i'
		reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7' dum1-dum13 ///
			if core==1, noconstant
		eststo h`i'
		replace ssr1`v'=e(rss) if _n==`i'
		replace nobs`v'=e(N) if _n==`i'
				
		test pk_fin=pk_norm // amt test
		estadd scalar p_diff1 = r(p)
		test srx_norm_prv=srx_fin_prv // amt test
		estadd scalar p_diffsrx = r(p)
		sum pk_norm if e(sample)
		estadd scalar Norm = r(sum)
		sum pk_fin if e(sample)
		estadd scalar Fin = r(sum)					
		
		replace lrgdpnlp0 = _b[pk_norm] + 0*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpnlp1 = _b[pk_norm] + 1*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpnlp2 = _b[pk_norm] + 2*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpnlp3 = _b[pk_norm] + 3*_b[srx_norm_prv]   if _n == `i'+1
		replace lrgdpflp0 = _b[pk_fin] + 0*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpflp1 = _b[pk_fin] + 1*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpflp2 = _b[pk_fin] + 2*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpflp3 = _b[pk_fin] + 3*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf050 = _b[pk_fin] + 0.50*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf175 = _b[pk_fin] + 1.75*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf275 = _b[pk_fin] + 2.75*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf375 = _b[pk_fin] + 3.75*_b[srx_fin_prv]   if _n == `i'+1

		}
	}
}

sum ssr0
scalar ssr0_ = r(sum)
sum ssr1
scalar ssr1_ = r(sum)
sum nobs
scalar nobs_ = r(sum)
scalar df1=10
scalar df2=nobs_ -20
scalar lmnew2 = ( (ssr0_-ssr1_)/df1 ) / ( ssr1_ / (df2) )
scalar psrxnew2 = Ftail(df1,df2,lmnew2)

local note1 = "LM test: All excess credit coefficients equal zero: "
local note2 = "F("+string(df1)+","+string(df2) + ") = "+string(lmnew2,"%9.3f") + "; "
local note3 = "p = "+string(psrxnew2,"%9.3f")
local note0 = "`note1'"+"`note2'"+"`note3'"

* p_diff1 is p value for F test of coefficients: Normal = Financial
esttab h1 h2 h3 h4 h5, ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin srx_norm_prv srx_fin_prv) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins and Excess Credit)

esttab h1 h2 h3 h4 h5 using ../tables/table8.tex , replace ///
	scalars(Norm Fin p_diff1 p_diffsrx) sfmt(2) obslast se label star(+ 0.10 * 0.05) ///
	addnote("`note0'" ///
	"Dependent variable: log real gdp per capita" ///
	"Year 0 controls not shown: drprv dlrgdp dlcpi dlriy stir ltrate cay" ///
	"l.drprv l.dlrgdp l.dlcpi l.dlriy l.stir l.ltrate l.cay") ///
	keep(pk_norm pk_fin srx_norm_prv srx_fin_prv) ///
	title(LP Conditional Paths -- 7 Variable System, Normal v. Financial Bins and Excess Credit)

eststo clear

drop ssr0* ssr1* nobs*
scalar drop ssr0_ ssr1_ nobs_ df1 df2

*********** LP Conditional 2 bins + cts exc cred (adds `rhs7' controls) 7 vars exGD  *********

* force sort tsset again
sort ccode year
tsset ccode year, yearly

foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		qui reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7' dum1-dum13 ///
			if core==1 & (year<1928|year>1946), noconstant //alt
		qui reg `v'`i' pk_norm pk_fin `rhs7' dum1-dum13 ///
			if e(sample)==1, noconstant // null, same sample

		replace ssr0`v'=e(rss) if _n==`i'
		reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7' dum1-dum13 ///
			if core==1 & (year<1928|year>1946), noconstant
		eststo h`i'
		replace ssr1`v'=e(rss) if _n==`i'
		replace nobs`v'=e(N) if _n==`i'
				
		test pk_fin=pk_norm // amt test
		estadd scalar p_diff1 = r(p)
		test srx_norm_prv=srx_fin_prv // amt test
		estadd scalar p_diffsrx = r(p)
		sum pk_norm if e(sample)
		estadd scalar Norm = r(sum)
		sum pk_fin if e(sample)
		estadd scalar Fin = r(sum)					

		}
	}
}

sum ssr0
scalar ssr0_ = r(sum)
sum ssr1
scalar ssr1_ = r(sum)
sum nobs
scalar nobs_ = r(sum)
scalar df1=10
scalar df2=nobs_ -20
scalar lmnew2 = ( (ssr0_-ssr1_)/df1 ) / ( ssr1_ / (df2) )
scalar psrxnew2 = Ftail(df1,df2,lmnew2)

local note1 = "LM test: All excess credit coefficients equal zero: "
local note2 = "F("+string(df1)+","+string(df2) + ") = "+string(lmnew2,"%9.3f") + "; "
local note3 = "p = "+string(psrxnew2,"%9.3f")
local note0 = "`note1'"+"`note2'"+"`note3'"

eststo clear

drop ssr0* ssr1* nobs*
scalar drop ssr0_ ssr1_ nobs_ df1 df2

gen Years = _n-1  if _n < 7
gen zero=0

****************************************************************************************
* plots
****************************************************************************************

* setup

local p1 f1
local p2 pt2

local irvars lrgdp lriy lcpi rprv cay stir ltrate

local tlrgdp "Real GDP per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

local s2f1 "1870-2008"
local s2pt2 "1948-2008"

foreach v of local justgdp {
	forvalues j=1/1 {
	
		gen up1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' + 1.96*se1_`v'_norm_`p`j''
		gen dn1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' - 1.96*se1_`v'_norm_`p`j''
		
	}
}

*********** fan chart ~~unconditional 3 bins~~

forvalues j=1/1 {
	foreach v of local justgdp {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin1_`p`j'' Years, lcolor(lavender) lpattern(dot) lwidth(thick)) ///
		(line b1_`v'_fin2_`p`j'' Years, lcolor(purple) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_fin3_`p`j'' Years, lcolor(blue) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(-1.5 3   "Fin. crisis + Lo credit", placement(w) color(lavender)) ///
		text(-4.2 5   "Fin. crisis + Med credit", placement(w) color(purple)) ///
		text(-5   3.8 "Fin. crisis + Hi credit", placement(w) color(blue)) ///
		text(+4.7 4 "Normal recessions, 95% c.i.", placement(w)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
}

graph export ../graphs/figure2a-Unconditional3bin_$today.pdf, replace //Alan
graph save   ../graphs/figure2a-Unconditional3bin_$today.gph, replace

graph drop _all

*********** fan chart ~~unconditional continuous~~

forvalues j=1/1 {
	foreach v of local justgdp {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (line lrgdpn0 Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line lrgdpn1 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpn2 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpn3 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpf0 Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(line lrgdpf1 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line lrgdpf2 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line lrgdpf3 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(+4.5  1.6 "Normal recessions (unconditional):", placement(e) color(blue)) ///
		text(+4    1.6 "+ Excess credit", placement(e) color(blue)) ///
		text(+3.5  1.6 "+ 1,2,3 %GDP/year", placement(e) color(blue)) ///
		text(-1.2  1.6 "Financial recessions (unconditional):", placement(e) color(red)) ///
		text(-1.7  1.6 "+ Excess credit =", placement(e) color(red)) ///
		text(-2.2  1.6 "+ 1,2,3 %GDP/year", placement(e) color(red)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
}

graph export ../graphs/figure2b-UnconditionalCts_$today.pdf, replace //Alan
graph save   ../graphs/figure2b-UnconditionalCts_$today.gph, replace

graph drop _all

*********** fan chart ~~conditional~~

forvalues j=1/1 {
	foreach v of local justgdp {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (line lrgdpnlp0 Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line lrgdpnlp1 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpnlp2 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpnlp3 Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line lrgdpflp0 Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(line lrgdpflp1 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line lrgdpflp2 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line lrgdpflp3 Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(+5.0    1.6 "Normal recessions (conditional):", placement(e) color(blue)) ///
		text(+4.3  1.6 "+ Excess credit", placement(e) color(blue)) ///
		text(+3.6    1.6 "+ 1,2,3 %GDP/year", placement(e) color(blue)) ///
		text(-1.4  1.6 "Financial recessions (conditional)", placement(e) color(red)) ///
		text(-2.1  1.6 "+ Excess credit =", placement(e) color(red)) ///
		text(-2.8  1.6 "+ 1,2,3 %GDP/year", placement(e) color(red)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
}

graph export ../graphs/figure3-ConditionalCts.pdf, replace //Alan
graph save   ../graphs/figure3-ConditionalCts.gph, replace

graph drop _all

*********** US fcast with unconditional 3 bin

* force sort tsset again
sort ccode year
tsset ccode year, yearly

* get actual data up to 2012 H1, see worksheets
append using ../data/USApath.dta
append using ../data/UKpath.dta


* use current Sep 7, 2012 forecasts to estimate y2012
list Year uk us if Years~=. & date~=.

* Fed June 2012 forecast has central tendency of real GDP for 2012yoy = 1.9% to 2.4%
* take midpoint 2.15% and subtract pop growth of 0.8% => estimate of 1.35% for 2012yoy
* SEPT FED UPDATE
* Fed Sept 2012 forecast has central tendency of real GDP for 2012yoy = 1.7% to 2.0%
* take midpoint 1.85% and subtract pop growth of 0.8% => estimate of 1.05% for 2012yoy

gen usf = usalrgdppc  if Years==4
replace usf = usf[_n-2] + 1.05 if Years==5

*Bank of England September forecast is for -0.7% real GDP growth 2012yoy
*subtract pop growth of 0.6% => estimate of -1.3% for 2012yoy
gen ukf = uk if Years==4
replace ukf = ukf[_n-2] - 1.3 if Years==5

list Year uk* us* if Years~=. & date~=.

forvalues j=1/1 {
	foreach v of local justgdp {

	if "`v'"=="lrgdp" & "`j'"=="1" {
			twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin2_`p`j'' Years, lcolor(purple) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_fin3_`p`j'' Years, lcolor(blue) lpattern(dash) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(scatter usalrgdppc Years, c(l) mc(maroon) lcolor(maroon) lwidth(thick) lpattern(solid))  ///
		(scatter usf Years, m(Sh) c(l) mc(maroon) lcolor(maroon) lwidth(thick) lpattern(dot))  ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(-4.7 5 "Financial crisis + Med credit boom", placement(w) color(purple)) ///
		text(-5.2 5 "Financial crisis + Hi credit boom", placement(w) color(blue)) ///
		text(-0.9 4 "US 2007 (Financial-Mid/Hi)", placement(w) color(maroon)) ///
		text(+3   3 "Normal recessions, 95% c.i.", placement(w)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
		
		
	}
	}
}

graph export ../graphs/figure5a_USApath_Unconditional_$today.pdf, replace //Alan
graph save   ../graphs/figure5a_USApath_Unconditional_$today.gph, replace

outsheet ///
	Years up1_lrgdp* dn1_lrgdp* b1_lrgdp* usalrgdppc usf ///
	using ../graphs/figure5a_USApath_Unconditional_$today.csv ///
	if Years~=., comma replace


*********** US fcast with normalization of RHS controls 2007 = historical mean values

* LP Conditional 2 bins + cts (adds `rhs7' controls) 7 var system \
* now use RHS 7 variables restandardized to usa 2007 = historical avg

** plot

local p1 f1
local p2 pt2

local irvars lrgdp lriy lcpi rprv cay stir ltrate

local tlrgdp "Real GDP per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

local s2f1 "1870-2008"
local s2pt2 "1946-2008"

forvalues j=1/1 {
	foreach v of local justgdp {

	if "`v'"=="lrgdp" & "`j'"=="1" {
			twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(rarea lrgdpf050 lrgdpf275 Years, ///
				fcolor(yellow) lcolor(yellow) lpattern(solid)) ///
		(line lrgdpf050 Years, lcolor(maroon) lpattern(solid) lwidth(thick)) ///
		(line lrgdpf275 Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(scatter usalrgdppc Years, c(l) mc(blue) lcolor(blue) lwidth(thick) lpattern(solid))  ///
		(scatter usf Years, m(Oh) c(l) mc(blue) lcolor(blue) lwidth(thick) lpattern(dot))  ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(5.5 0 "Predicted:", placement(e)) ///
		text(5.0 0 "Financial crisis + exc cred +0.50% (USA)", placement(e) color(maroon)) ///
		text(4.5 0 "Financial crisis + exc cred +2.75% (USA + shadow est.)", placement(e) color(red)) ///
		text(-0.6 4 "USA, 2007-11 and 2012e", placement(w) color(blue)) ///
		text(+3.5 1 "Predicted:", placement(e)) ///
		text(+3   1 "Normal recessions, 95% c.i.", placement(e)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		/* ylabel(-12(3)0) */ ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
}

graph export ../graphs/figure5b_USApath_Conditional_$today.pdf, replace //Alan
graph save   ../graphs/figure5b_USApath_Conditional_$today.gph, replace

outsheet ///
	Years up1_lrgdp* dn1_lrgdp* b1_lrgdp* lrgdpf050 lrgdpf275 usalrgdppc usf ///
	using ../graphs/figure5b_USApath_Unconditional_$today.csv ///
	if Years~=., comma replace


*********** US fcast with normalization of RHS controls 2007 = historical mean values
** add the UK and use IMF WEO Oct 2012 data

* LP Conditional 2 bins + cts (adds `rhs7' controls) 7 var system \
* now use RHS 7 variables restandardized to usa 2007 = historical avg

* load the IMF WEO Oct 2012 data
append using ../data/IMF_WEO_Oct2012.dta

drop if usyweo~=. & Years>5
drop if ukyweo~=. & Years>5

gen logusweo = log(usyweo)
sum logusweo if Years==0
replace logusweo = (log(usyweo) -r(mean) ) * 100

gen logukweo = log(ukyweo)
sum logukweo if Years==0
replace logukweo = (log(ukyweo) -r(mean) ) * 100


** plot

local p1 f1
local p2 pt2

local irvars lrgdp lriy lcpi rprv cay stir ltrate

local tlrgdp "Real GDP per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

local s2f1 "1870-2008"
local s2pt2 "1946-2008"


*********** redo US fcast with normalization of RHS controls 2007 = USA 2007 values

* LP Conditional 2 bins + cts (adds `rhs7' controls) 7 var system \
* now use RHS 7 variables restandardized to usa 2007 = 0

* force sort tsset again
sort ccode year
tsset ccode year, yearly

* RHS 7 variable set with means = 0 for USA 2007 peak for OOS US forecast 2007-12

local rhs7USA7 drprvUSA7 dlrgdpUSA7 dlcpiUSA7 dlriyUSA7 stirUSA7 ltrateUSA7 cayUSA7 ///
		l.drprvUSA7 l.dlrgdpUSA7 l.dlcpiUSA7 ///
		l.dlriyUSA7 l.stirUSA7 l.ltrateUSA7 l.cayUSA7	
			
local rhslevels drprv dlrgdp dlcpi dlriy stir ltrate cay
foreach v of local rhslevels {
		gen tempv1 = `v'   if iso=="USA" & year==2007
		egen tempv2 = mean(tempv1)   
		gen `v'USA7= `v' - tempv2
		drop tempv1 tempv2
		}

* redo forecasts with new RHS7
foreach v of local justgdp {
	gen ssr0`v'=.
	gen ssr1`v'=.
	gen nobs`v'=.
	forvalues i =1/5 {
		forvalues j= 1/1 {
		
		reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7USA7' dum1-dum13 ///
			if core==1, noconstant
		
		replace lrgdpf050 = _b[pk_fin] + 0.50*_b[srx_fin_prv]   if _n == `i'+1
		replace lrgdpf275 = _b[pk_fin] + 2.75*_b[srx_fin_prv]   if _n == `i'+1

		}
	}
}


restore 

*******************************************************************************
*******************************************************************************
**** Complete set of IRFs for all 7 variables
*******************************************************************************
*******************************************************************************

* 7 variable LP Conditional
* with 1 se shock to excess credit in each bin
* full set of IRFs

preserve

local beta pk_norm pk_fin srx_norm_prv srx_fin_prv

* country fixed effects CFE restricted regression coefficients
forvalues i =1/14 {
	gen      dum`i'=0
	replace  dum`i'= 1 - 1/14   if ccode==`i'
	replace  dum`i'=   - 1/14   if ccode~=`i'
	}


*** generate the coefficient columns to be filled in with the results below
foreach v of local irvars {
	forvalues j=1/3 {
		
		* setup normal and normal +1sd excess 
		gen bn0_`v'_`p`j''=0
		gen sen0_`v'_`p`j''=0
		gen bn1_`v'_`p`j''=0
		gen sen1_`v'_`p`j''=0
		
		* setup fin and fin +1sd excess 
		gen bf0_`v'_`p`j''=0
		gen sef0_`v'_`p`j''=0
		gen bf1_`v'_`p`j''=0
		gen sef1_`v'_`p`j''=0
		
		foreach b of local beta { 

			gen b2_`b'_`v'_`p`j'' =0
			gen se2_`b'_`v'_`p`j'' =0

		}
	}
}

*** 1. grab the per-period srx_prv standard deviation 
*** 2. run a panel fixed effects regression of the cummulative change of the impulse response left-hand side variables on 
****** normal and financial recessions and excess crdit with a set of controls 
*** 3. create the linear combination of beta's and se's from normal recessions and excess credit 
****** scaled by it's period sd, store these results as b2_lcsd and se2_lcsd
*** 4. grab the beta's and se's from normal and fiancial recessions and excess credit, store these results as b2_ and se2_

forvalues j=1/1 {   // full sample = c1

	* save sd's for srxn and srxf
	sum srx_fin_prv if `c`j'' & pk_fin==1 & core==1
	local srx_fin_prv`j' = r(sd)
	sum srx_norm_prv if `c`j'' & pk_norm==1 & core==1
	local srx_norm_prv`j' = r(sd)
	
	sum srx_prv                               if `c`j'' & pk_fin==1 & core==1
	replace srx_fin_prv = srx_prv - r(mean)   if `c`j'' & pk_fin==1 & core==1
	replace srx_fin_prv = 0                   if `c`j'' & pk_fin==0 & core==1
	
	sum srx_prv                               if `c`j'' & pk_norm==1 & core==1
	replace srx_norm_prv = srx_prv - r(mean)  if `c`j'' & pk_norm==1 & core==1
	replace srx_norm_prv = 0                  if `c`j'' & pk_norm==0 & core==1
	
	**** standardizing RHS
				
		* do some manual standardizing (to demean) the rhs set
		* for proper simple path fcast
		
		local rhslevels drprv dlrgdp dlcpi dlriy stir ltrate cay
		foreach v of local rhslevels {
		gen tempv1 = `v' if `c`j'' 
		egen tempv2 = std(tempv1) if `c`j'' 
		replace `v'=tempv2
		drop tempv1 tempv2
			}
		
	
	foreach v of local irvars {
		forvalues i =1/5 {
		
			reg `v'`i' pk_norm pk_fin srx_norm_prv srx_fin_prv `rhs7' dum1-dum13 ///
				if `c`j'' & core==1, noconstant
		
			replace bn0_`v'_`p`j''  = _b[pk_norm] if _n == `i'+1
			replace sen0_`v'_`p`j'' = _se[pk_norm] if _n == `i'+1
			replace bf0_`v'_`p`j''  = _b[pk_fin] if _n == `i'+1
			replace sef0_`v'_`p`j'' = _se[pk_fin] if _n == `i'+1

			lincom pk_norm + (srx_norm_prv*`srx_norm_prv`j'') 
			replace bn1_`v'_`p`j''  = r(estimate) if _n == `i'+1
			replace sen1_`v'_`p`j'' = r(se)       if _n == `i'+1
				
			lincom pk_fin + (srx_fin_prv*`srx_fin_prv`j'') 
			replace bf1_`v'_`p`j''  = r(estimate) if _n == `i'+1
			replace sef1_`v'_`p`j'' = r(se)       if _n == `i'+1
				
			foreach b of local beta {
				qui replace b2_`b'_`v'_`p`j'' =  _b[`b'] if _n == `i'+1
				qui replace se2_`b'_`v'_`p`j'' = _se[`b'] if _n == `i'+1
			}
		}
	}
}

gen Years = _n-1 if _n <= 6
gen zero = 0 if _n <= 6

*** generate upper and lower bounds for normal recessions for each ir var by period
foreach v of local irvars {
	forvalues j=1/3 {
		gen upbn0_`v'_`p`j'' = bn0_`v'_`p`j'' + 1.96*sen0_`v'_`p`j'' if _n <= 6
		gen dnbn0_`v'_`p`j'' = bn0_`v'_`p`j'' - 1.96*sen0_`v'_`p`j'' if _n <= 6
		}
	}

*** plot the irfs

forvalues j=1/1 {  // c1 only
	foreach v of local irvars {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(-1 5 "Financial", placement(w) color(red)) ///
		text(4 3 "Normal", placement(w)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="lrgdp" & "`j'"!="1" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
		}
	if "`v'"=="lcpi" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="lriy" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="rprv" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="cay" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="stir" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="ltrate" {
		twoway (rarea upbn0_`v'_`p`j'' dnbn0_`v'_`p`j''  Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line bf1_`v'_`p`j'' Years, lcolor(red) lpattern(shortdash) lwidth(thick)) ///
		(line bf0_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line bn1_`v'_`p`j'' Years, lcolor(blue) lpattern(dot) lwidth(thick)) ///
		(line bn0_`v'_`p`j'' Years, lcolor(blue) lpattern(solid) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	
	}
	
	* blank chart for holes
	twoway scatteri 1 1,               ///
       msymbol(i)                  ///
       ylab("") xlab("")           ///
       ytitle("") xtitle("")       ///
       yscale(off) xscale(off)     ///
       plotregion(lpattern(blank)) ///
       name(blank`j', replace) scheme(s1color) 
       
	graph combine lrgdp`j' lriy`j' lcpi`j', scheme(s1color) ///
	graphregion(color(white)) plotregion(color(white)) ///
	rows(1) cols(3) imargin(tiny) name(g`j'a, replace)

	graph combine rprv`j' stir`j' ltrate`j', scheme(s1color) ///
	graphregion(color(white)) plotregion(color(white)) ///
	rows(1) cols(3) imargin(tiny) name(g`j'b, replace)

	graph combine cay`j' blank`j' blank`j' ,  scheme(s1color) ///
	graphregion(color(white)) plotregion(color(white)) ///
	rows(1) cols(3) imargin(tiny) name(g`j'c, replace)

}

*** combine the graphs from the two sample periods
	graph combine g1a g1b g1c, ///
	title("Cumulative Change From the Start of the Recession, 1870-2008", size(small)) ///
	graphregion(color(white)) scheme(s1color) ///
	rows(3) ysize(3) xsize(3) imargin(tiny)
	
graph save ../graphs/figure4_LP7_$today.gph, replace
graph export ../graphs/figure4_LP7_$today.eps, mag(200) orientation() replace
graph export ../graphs/figure4_LP7_$today.pdf, replace

graph drop _all

restore
