
preserve

set more off

local treatment a r
local varlist lrgdp rprv

foreach t of local treatment {
	foreach v of local varlist {
	
		replace `t'x_`v'_bb = 100*`t'x_`v'_bb
	}
}


local treatment a d r
local lev Low_Leverage High_Leverage

local la "Low_Leverage_Amplitude"
local ld "Low_Leverage_Duration"
local lr "Low_Leverage_Rate"

local ha "High_Leverage_Amplitude"
local hd "High_Leverage_Duration"
local hr "High_Leverage_Rate"

local p1 "Full Sample"
local p2 "Pre-World War II"
local p3 "Post-World War II"

* amt make the sample core only
local c1 year > 1869 & core==1 
local c2 year < 1940 & core==1 
local c3 year > 1946 & core==1 


gen n = _n if _n < 12
gen period =""
gen stat =""
	
foreach l of local lev {
	
	gen `l'_Amplitude=.			
	gen `l'_Rate=.
	gen `l'_Duration=.
	}

forvalues i=1/3 {

	local z = (`i'*3)-1
	
		foreach t of local treatment {
			
			sum srx_prv if `c`i'' & srx_prv !=0 & `t'x_lrgdp_bb !=0 & war!=1
			local mlev = r(mean)
			
			sum `t'x_lrgdp_bb if srx_prv <= `mlev' & `c`i'' & srx_prv !=0 & `t'x_lrgdp_bb !=0 & war!=1
			
			replace `l`t'' = r(mean) if n==`z'
			replace `l`t'' = -1*r(sd) if n==`z'+1		// make negative for easy formatting in excel
			replace `l`t'' = r(N) if n==`z'+2 
			
			sum `t'x_lrgdp_bb if srx_prv > `mlev' & `c`i'' & srx_prv !=0 & `t'x_lrgdp_bb !=0 & war!=1
			
			replace `h`t'' = r(mean) if n==`z'
			replace `h`t'' = -1*r(sd) if n==`z'+1		// make negative for easy formatting in excel
			replace `h`t'' = r(N) if n==`z'+2
			
			replace stat = "Mean" if n==`z'
			replace stat = "Standard Deviation" if n==`z'+1
			replace stat = "Observations" if n==`z'+2
		
		}
			replace period = "`p`i''" if n==`z'
}

export excel ///
	period stat ///
	Low_Leverage_Amplitude High_Leverage_Amplitude ///
	Low_Leverage_Duration High_Leverage_Duration ///
	Low_Leverage_Rate High_Leverage_Rate  ///
		using ../tables/table2.xlsx, ///
		firstrow(variables) sheet(table2) sheetreplace


** generate Table 2 in LaTeX in 3 parts for each sample period

forvalues i=1/3 {  // 3 sample periods
			
		sum srx_prv if `c`i'' & core==1
		local mlev = r(mean)
		
		gen alo = ax_lrgdp_bb if srx_prv <= `mlev' & `c`i'' & core==1
		gen ahi = ax_lrgdp_bb if srx_prv >  `mlev' & `c`i'' & core==1
		gen dlo = dx_lrgdp_bb if srx_prv <= `mlev' & `c`i'' & core==1
		gen dhi = dx_lrgdp_bb if srx_prv >  `mlev' & `c`i'' & core==1
		gen rlo = rx_lrgdp_bb if srx_prv <= `mlev' & `c`i'' & core==1
		gen rhi = rx_lrgdp_bb if srx_prv >  `mlev' & `c`i'' & core==1
		
		label var alo "Ampl lo exc cred"
		label var ahi "Ampl hi exc cred"
		label var dlo "Durn lo exc cred"
		label var dhi "Durn hi exc cred"
		label var rlo "Rate lo exc cred"
		label var rhi "Rate hi exc cred"
		
		estpost tabstat  alo ahi dlo dhi rlo rhi if core==1,  ///
				statistics(mean sd count)
		
		esttab, ///
			cells("alo(fmt(1)) ahi dlo dhi rlo rhi") nomtitle nonumber
		

		esttab using ../tables/table2_part`i'.tex, replace ///
			cells("alo(fmt(1)) ahi dlo dhi rlo rhi") nomtitle nonumber ///
			title("`p`i''")


		drop alo ahi dlo dhi rlo rhi
			
		}



restore



