version 12.0
**** Get the data ready AMT 10/2/2012

****** Creat ccode and first sort *********************************************
drop ccode*
egen ccode = group(iso)
sort ccode year
tsset ccode year, yearly


****** Data transformations **************************************************

gen lrgdp   = log(rgdpbarro)		// real GDP index from Barro
gen lrcon   = log(rconsbarro)		// real consumption index from Barro
gen lmoney  = log(money)			// M2, more or less
gen lstocks = log(stocks)			// Stock indices
gen lnarrow = log(narrowm)			// M1, more or less
gen lcpi    = log(cpi)				// CPI
gen cay		= ca/gdp				// Current Account over GDP ratio
gen lpop    = log(pop)
gen lloans  = log(loans1)

gen rprv  = lloans - lcpi - lpop 	// real per capita private loans

gen riy = iy*rgdpbarro				// real per capita investment
gen lriy = log(riy)

gen rlmoney = lmoney - lcpi

gen dlrgdp  = 100*d.lrgdp			// Annual real per capita GDP growth in percent
gen dlriy	= 100*d.lriy			// Annual real per capita investment growth in percent
gen dlcpi   = 100*d.lcpi			// Annual inflation in percent
gen dlrcon  = 100*d.lrcon			// Annual real consumption growth in percent

gen drprv = 100*d.rprv					// Annual real per capita private loan growth 
gen drlmoney= 100*d.rlmoney 			// Annual Growth in M2 ??100??

replace cay = 100*cay
replace stir = 100*stir
replace ltrate = 100*ltrate 


******** Generates NBER peak and trough dummies + recession indicator ***************

qui include ../auxprograms/NBER.do

gen war=0
replace war = 1 if year>=1914 & year<=1919
replace war = 1 if year>=1939 & year<=1947

******* Business Cycle Peaks and Troughs using Real GDP per capita (Barro-Ursua)

* This does Bry and Boschan (1971) on yearly data

qui include ../auxprograms/annual_brybos_loop.do

****** Calculate Cyclical Amplitudes, Durations and Rates ******************************

* Start with Business Cycles

qui include ../auxprograms/peak_dummies_August2012Alan.do

gen pk_comb =  pk_norm + pk_fin + pk_glob
replace pk_bb = 1 if pk_bb==0 & pk_comb==1

local yvars lrgdp rprv /*rpub rtot*/
local cycle bb

include ../auxprograms/amplitude_201204.do


**** Define the Excess Credit variable "srx" (more transforms below) ******************

gen srx_prv = .

*** SRX is rate (pct pt per year) of (loan/GDP) ratio during the prior expansion
gen loansgdp = loans1/gdp
replace srx_prv = 100*(loansgdp-loansgdp[_n-dx_lrgdp_bb]) / dx_lrgdp_bb if dx_lrgdp_bb > 0

local debt prv /*pub tot*/

replace pk_fin = pk_fin + pk_glob

******** Sample housekeeping with the data  ********************************************

* force sort tsset again
sort ccode year
tsset ccode year, yearly

gen f1war = f1.war
gen f2war = f2.war
gen f3war = f3.war
gen f4war = f4.war
gen f5war = f5.war
gen l1war = l1.war
gen l2war = l2.war

gen      war5f2l = 0
replace  war5f2l = 1 if l2.war==1
replace  war5f2l = 1 if l1.war==1
replace  war5f2l = 1 if    war==1
replace  war5f2l = 1 if f1.war==1
replace  war5f2l = 1 if f2.war==1
replace  war5f2l = 1 if f3.war==1
replace  war5f2l = 1 if f4.war==1
replace  war5f2l = 1 if f5.war==1

** Define core dataset used for the regressions here and later
* full sample, no windows with wars +5 or -2
* last complete 5 year window ends at 2003+5 = 2008
* we end up with 1870-1908, 1921-1933, 1948-2003

gen core = 1 ///
	if (year>=1870&year<=1908) | (year>=1921&year<=1933) | (year>=1948&year<=2003)
	
replace core = . if pk_norm==0 & pk_fin==0
replace core = . if f1.lrgdp==.
replace core = . if f2.lrgdp==.
replace core = . if f3.lrgdp==.
replace core = . if f4.lrgdp==.
replace core = . if f5.lrgdp==.

* main sample all & postwar
local c1 core==1
local c2 core==1 & year>1945

local p1 f1
local p2 pt2

* data excluded from the regressions (peak but not in core)
gen dropped = 1 if pk_norm==1 | pk_fin==1
replace dropped = . if core==1


********** Transform to make demeaned excess credit variables in each bin ***************

*interactions with F and N dummies
foreach d of local debt {
	gen srx_norm_`d' = srx_`d'*pk_norm
	gen srx_fin_`d'  = srx_`d'*pk_fin 
}


* demean by bin to standardize the treatment terms individually

sum srx_norm_prv if pk_norm==1 & core==1 // ****** demean within norm bin
replace srx_norm_prv = srx_norm_prv -r(mean) if pk_norm==1 & core

sum srx_fin_prv if pk_fin==1 & core==1 // ****** demean within fin bin
replace srx_fin_prv = srx_fin_prv -r(mean) if pk_fin==1 & core


* check what is in the core sample and what is omitted 

sum iso year pk_norm pk_fin srx_prv if core==1
list iso year pk_norm pk_fin srx_prv srx_fin_prv srx_norm_prv if core==1


* tercile indicators by bin

xtile srx_fin_prv_bin  = srx_fin_prv   if pk_fin==1,   nq(3)
xtile srx_norm_prv_bin = srx_norm_prv  if pk_norm==1,  nq(3) 

gen pk_fin1 = cond(srx_fin_prv_bin==1,pk_fin,0) ///
	if pk_norm==1 | (pk_fin==1 & srx_fin_prv_bin~=.)
gen pk_fin2 = cond(srx_fin_prv_bin==2,pk_fin,0) ///
	if pk_norm==1 | (pk_fin==1 & srx_fin_prv_bin~=.)
gen pk_fin3 = cond(srx_fin_prv_bin==3,pk_fin,0) ///
	if pk_norm==1 | (pk_fin==1 & srx_fin_prv_bin~=.)
	
sum iso year pk_norm pk_fin srx_prv srx_fin_prv srx_norm_prv if dropped==1
list iso year pk_norm pk_fin srx_prv srx_fin_prv srx_norm_prv if dropped==1


**************** Look at excess overall and by pctile and 2007/08 relative (oos)
/*
sum srx_prv  if pk_norm==1 & core==1 , detail
sum srx_prv  if pk_fin==1 & core==1 , detail
sum srx_prv  if (pk_norm==1|pk_fin==1)& core==1 , detail

centile (srx_prv) if pk_fin==1 & core==1 , centile(50 55 60 65 70 75 80 85 90 95)
centile (srx_prv) if pk_fin==1 & core==1 , centile(50 66)

xtile srx_fin_prv_pctile  = srx_prv   if pk_fin==1 & core==1 ,   nq(100)

* what does 2007/08 look like (NOT in core sample)
list iso year pk_fin srx_fin_prv srx_fin_prv_pctile if year>2000 & pk_fin==1
*/
*********** Make summary statistics table for excess credit ****************************

gen pktype = ""
replace pktype = "Financial" if pk_fin==1&core==1
replace pktype = "Normal" if pk_norm==1&core==1
gen pktypeall = "All" if (pk_norm==1|pk_fin==1)&core==1

* do the table
eststo clear
label var srx_prv "Excess credit measure"

* have to sort
sort pktypeall
by pktypeall: ///
	eststo: quietly estpost summarize srx_prv if pktype~=""&core==1, listwise
sort pktype
by pktype: ///
	eststo: quietly estpost summarize srx_prv if pktype~=""&core==1, listwise
esttab using ../tables/table3.tex, replace ///
	title("Summary statistics for the "Treatment" variables") ///
	cells("mean(fmt(2)) sd(fmt(2))") label nodepvar
eststo clear



******* save and move on ************

* force sort tsset again
sort ccode year
tsset ccode year, yearly

save ../data/private, replace

