gen Years = _n if _n < 6
gen zero = 0 if _n < 6

*** Sample period names: f1 = full sample; pt2 = post WWII sample
local p1 f1
local p2 pt2

*** impulse response variables
local irvars lrgdp lriy lcpi lrcon rprv rlmoney cay stir ltrate

*** make graph titles
local tlrgdp "Real GDP per capita"
local tlrcon "Real Consumption per capita"
local tlriy "Real Investment per capita"
local trprv "Real Lending per capita"
local trlmoney "Real M2"
local tlcpi "CPI Prices"
local tstir "Govt. Short-term Interest Rates"
local tltrate "Govt. Long-term Interest Rates"
local tcay "Current Account to GDP Ratio"

*** make graph subtitles 
local s2f1 "1870-2008"
local s2pt2 "1946-2008"

*** generate upper and lower bounds for normal recessions for each ir var by period
foreach v of local irvars {
	forvalues j=1/2 {
	
		gen up1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' + 1.96*se1_`v'_norm_`p`j''
		gen dn1_`v'_norm_`p`j'' = b1_`v'_norm_`p`j'' - 1.96*se1_`v'_norm_`p`j''
		
	}
}

*** graph the beta's from the average effects regression of cumm change AND panel fixed effects regression of cumm change
*** b1_ --> the beta's from the normal and financial indicator (from the average effects regression) 
*** up1_ and dn1_ --> the upper and lower bounds for normal recessions (from the average effects regression) 
*** b3_srx_ --> the combination of the financial recessions and excess credit with excess credit scaled 
****** 2x it's per-period sd (from the conditional effects regression) 
forvalues j=1/2 {
	foreach v of local irvars {

	if "`v'"=="lrgdp" & "`j'"=="1" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b3_srx_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///   
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		text(-2 5 "Financial crisis", placement(w) color(red)) ///
		text(4 3 "Normal recession", placement(w)) ///
		title(`t`v'',  color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
		if "`v'"=="lrgdp" & "`j'"=="2" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b3_srx_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
		}
	if "`v'"=="lcpi" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b3_srx_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	if "`v'"=="lriy" {
		twoway (rarea up1_`v'_norm_`p`j'' dn1_`v'_norm_`p`j'' Years, ///
				fcolor(gs12) lcolor(white) lpattern(solid)) ///
		(line b1_`v'_fin_`p`j'' Years, lcolor(red) lpattern(dash) lwidth(thick)) ///
		(line b3_srx_`v'_`p`j'' Years, lcolor(red) lpattern(solid) lwidth(thick)) ///
		(line b1_`v'_norm_`p`j'' Years, lcolor(black) lwidth(thick)) ///
		(line zero Years, lcolor(black)), ///
		ylabel(, nogrid) ///
		title(`t`v'', color(black) size(medium)) ytitle("", size(medsmall)) xtitle("", size(medsmall)) ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(off) name(`v'`j', replace)
	}
	}
	graph combine lrgdp`j' lriy`j' lcpi`j', ///
	title(`s2`p`j''', color(black) size(medsmall)) ///
	graphregion(color(white)) plotregion(color(white)) ///
	row(1) imargin(tiny) name(g`j', replace)
}

*** combine the graphs from the two sample periods
	graph combine g1 g2, ///
	title("Cumulative Percent Change From the Start of the Recession", size(small)) ///
	graphregion(color(white)) plotregion(color(white)) ///
	row(2) ysize(3) xsize(4) imargin(tiny)
	
graph save ../graphs/uncond_av_lncsd_$today.gph, replace
graph export ../graphs/uncond_av_lncsd_$today.eps, mag(200) orientation() replace
graph export ../graphs/uncond_av_lncsd_$today.pdf, replace

graph drop _all

